Authors
=======

Hydra (ndn-hydra) is a mutli-unviersity project between UCLA and Tennesse Tech.

* Zixuan Zhong         <https://github.com/ZixuanZhong>
* Justin Presley       <https://github.com/justincpresley>
* Daniel Achee         <https://github.com/daniel-achee>
